@@ -17,6 +17,7 @@ import aws_cdk.aws_apigateway._jsii
 import aws_cdk.aws_apigatewayv2._jsii
 import aws_cdk.aws_appconfig._jsii
 import aws_cdk.aws_appflow._jsii
+import aws_cdk.aws_appintegrations._jsii
 import aws_cdk.aws_applicationautoscaling._jsii
 import aws_cdk.aws_applicationinsights._jsii
 import aws_cdk.aws_appmesh._jsii
@@ -49,6 +50,7 @@ import aws_cdk.aws_codestarconnections._jsii
 import aws_cdk.aws_codestarnotifications._jsii
 import aws_cdk.aws_cognito._jsii
 import aws_cdk.aws_config._jsii
+import aws_cdk.aws_customerprofiles._jsii
 import aws_cdk.aws_databrew._jsii
 import aws_cdk.aws_datapipeline._jsii
 import aws_cdk.aws_datasync._jsii
@@ -82,6 +84,7 @@ import aws_cdk.aws_globalaccelerator._jsii
 import aws_cdk.aws_glue._jsii
 import aws_cdk.aws_greengrass._jsii
 import aws_cdk.aws_greengrassv2._jsii
+import aws_cdk.aws_groundstation._jsii
 import aws_cdk.aws_guardduty._jsii
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_imagebuilder._jsii
@@ -90,6 +93,7 @@ import aws_cdk.aws_iot._jsii
 import aws_cdk.aws_iot1click._jsii
 import aws_cdk.aws_iotanalytics._jsii
 import aws_cdk.aws_iotevents._jsii
+import aws_cdk.aws_iotfleethub._jsii
 import aws_cdk.aws_iotsitewise._jsii
 import aws_cdk.aws_iotthingsgraph._jsii
 import aws_cdk.aws_iotwireless._jsii
@@ -103,6 +107,7 @@ import aws_cdk.aws_lakeformation._jsii
 import aws_cdk.aws_lambda._jsii
 import aws_cdk.aws_licensemanager._jsii
 import aws_cdk.aws_logs._jsii
+import aws_cdk.aws_lookoutmetrics._jsii
 import aws_cdk.aws_lookoutvision._jsii
 import aws_cdk.aws_macie._jsii
 import aws_cdk.aws_managedblockchain._jsii
@@ -116,6 +121,7 @@ import aws_cdk.aws_mwaa._jsii
 import aws_cdk.aws_neptune._jsii
 import aws_cdk.aws_networkfirewall._jsii
 import aws_cdk.aws_networkmanager._jsii
+import aws_cdk.aws_nimblestudio._jsii
 import aws_cdk.aws_opsworks._jsii
 import aws_cdk.aws_opsworkscm._jsii
 import aws_cdk.aws_pinpoint._jsii
@@ -155,14 +161,13 @@ import aws_cdk.aws_wafregional._jsii
 import aws_cdk.aws_wafv2._jsii
 import aws_cdk.aws_workspaces._jsii
 import aws_cdk.core._jsii
-import aws_cdk.yaml_cfn._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/cloudformation-include",
-    "1.96.0",
+    "1.102.0",
     __name__[0:-6],
-    "cloudformation-include@1.96.0.jsii.tgz",
+    "cloudformation-include@1.102.0.jsii.tgz",
 )
 
 __all__ = [
